Interface: ChartEvent | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartEvent

## # Properties

### # native

• native: `Event`

#### # Defined in

index.esm.d.ts:1407
(opens new window)

### # type

• type: `"resize"` | `"click"` | `"contextmenu"` | `"dblclick"` | `"keydown"` | `"keypress"` | `"keyup"` | `"mousedown"` | `"mouseenter"` | `"mousemove"` | `"mouseout"` | `"mouseup"`

#### # Defined in

index.esm.d.ts:1394
(opens new window)

### # x

• x: `number`

#### # Defined in

index.esm.d.ts:1408
(opens new window)

### # y

• y: `number`

#### # Defined in

index.esm.d.ts:1409
(opens new window)